@@ -90,6 +90,7 @@ def _append_math_eq_ne(func):
         @inner_wrapper.register(bool)
         @inner_wrapper.register(type(self))
         @inner_wrapper.register(jax.interpreters.partial_eval.DynamicJaxprTracer)
+        @inner_wrapper.register(jax.numpy.ndarray)
         def _(
             self,
             rhs: int
@@ -97,7 +98,8 @@ def _append_math_eq_ne(func):
             | complex
             | bool
             | type(self)
-            | jax.interpreters.partial_eval.DynamicJaxprTracer,
+            | jax.interpreters.partial_eval.DynamicJaxprTracer
+            | jax.numpy.ndarray,
         ):
             # this function is handling all the numeric types
             return _dispatched_op_tree_map(func, self, rhs)
@@ -146,19 +148,10 @@ def _append_math_eq_ne(func):
             # this mechanism could filter by multiple metadata, however possible drawbacks
             # are that some data structures might have the same metadata for all of it's elements (list/dict/tuple)
             # and this would filter out all the elements without distinction
-
-            def in_metadata(field_item):
-                kws, vals = zip(*where.items())
-                return all(
-                    field_item.metadata.get(kw, False)
-                    and (field_item.metadata[kw] == val)
-                    for kw, val in zip(kws, vals)
-                )
-
             return _pytree_map(
                 tree,
                 # condition to check for each dataclass field
-                cond=lambda _, field_item, __: in_metadata(field_item),
+                cond=lambda _, field_item, __: (where == field_item.metadata),
                 # if the condition is True, then broadcast True to the children
                 true_func=lambda _, __, node_item: node_true(node_item),
                 # if the condition is False, then broadcast False to the children
